@@ -5,7 +5,7 @@
  *
  * The MIT License
  *
- * @copyright Copyright (c) 2017-2021 TileDB Inc.
+ * @copyright Copyright (c) 2017-2023 TileDB Inc.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -32,6 +32,8 @@
 
 #include <test/support/tdb_catch.h>
 #include "test/support/src/helpers.h"
+#include "test/support/src/temporary_local_directory.h"
+#include "tiledb/api/c_api/vfs/vfs_api_internal.h"
 #include "tiledb/sm/c_api/tiledb.h"
 #include "tiledb/sm/misc/utils.h"
 #ifdef _WIN32
@@ -42,12 +44,16 @@
 #endif
 
 #include <iostream>
+#include <optional>
 #include <sstream>
 #include <thread>
 
 using namespace tiledb::test;
 
 struct VFSFx {
+  // The unique directory object
+  tiledb::sm::TemporaryLocalDirectory temp_dir_{"tiledb_test_"};
+
   const std::string HDFS_TEMP_DIR = "hdfs://localhost:9000/tiledb_test/";
   const std::string S3_PREFIX = "s3://";
   const std::string S3_BUCKET = S3_PREFIX + random_name("tiledb") + "/";
@@ -60,18 +66,13 @@ struct VFSFx {
 #ifndef _WIN32
       "file://" +
 #endif
-      tiledb::test::get_temp_path();
+      temp_dir_.path();
   const std::string MEMFS_TEMP_DIR = std::string("mem://tiledb_test/");
 
   // TileDB context and vfs
   tiledb_ctx_t* ctx_;
   tiledb_vfs_t* vfs_;
 
-  // Supported filesystems
-  bool supports_s3_;
-  bool supports_hdfs_;
-  bool supports_azure_;
-
   // Functions
   VFSFx();
   ~VFSFx();
@@ -83,19 +84,10 @@ struct VFSFx {
   void check_append(const std::string& path);
   void check_ls(const std::string& path);
   static std::string random_name(const std::string& prefix);
-  void set_supported_fs();
-  void set_num_vfs_threads(unsigned num_threads);
 };
 
 VFSFx::VFSFx() {
-  ctx_ = nullptr;
-  vfs_ = nullptr;
-
-  // Supported filesystems
-  set_supported_fs();
-
-  // Create context and VFS with 1 thread
-  set_num_vfs_threads(1);
+  create_ctx_and_vfs(&ctx_, &vfs_);
 }
 
 VFSFx::~VFSFx() {
@@ -103,93 +95,8 @@ VFSFx::~VFSFx() {
   tiledb_ctx_free(&ctx_);
 }
 
-void VFSFx::set_supported_fs() {
-  tiledb_ctx_t* ctx = nullptr;
-  REQUIRE(tiledb_ctx_alloc(nullptr, &ctx) == TILEDB_OK);
-
-  bool supports_gcs;  // unused
-  get_supported_fs(
-      &supports_s3_, &supports_hdfs_, &supports_azure_, &supports_gcs);
-
-  tiledb_ctx_free(&ctx);
-}
-
-void VFSFx::set_num_vfs_threads(unsigned num_threads) {
-  if (vfs_ != nullptr)
-    tiledb_vfs_free(&vfs_);
-  if (ctx_ != nullptr)
-    tiledb_ctx_free(&ctx_);
-
-  // Create TileDB context
-  tiledb_config_t* config = nullptr;
-  tiledb_error_t* error = nullptr;
-  REQUIRE(tiledb_config_alloc(&config, &error) == TILEDB_OK);
-  REQUIRE(error == nullptr);
-  if (supports_s3_) {
-#ifndef TILEDB_TESTS_AWS_S3_CONFIG
-    REQUIRE(
-        tiledb_config_set(
-            config, "vfs.s3.endpoint_override", "localhost:9999", &error) ==
-        TILEDB_OK);
-    REQUIRE(
-        tiledb_config_set(config, "vfs.s3.scheme", "https", &error) ==
-        TILEDB_OK);
-    REQUIRE(
-        tiledb_config_set(
-            config, "vfs.s3.use_virtual_addressing", "false", &error) ==
-        TILEDB_OK);
-    REQUIRE(
-        tiledb_config_set(config, "vfs.s3.verify_ssl", "false", &error) ==
-        TILEDB_OK);
-    REQUIRE(error == nullptr);
-#endif
-  }
-  if (supports_azure_) {
-    REQUIRE(
-        tiledb_config_set(
-            config,
-            "vfs.azure.storage_account_name",
-            "devstoreaccount1",
-            &error) == TILEDB_OK);
-    REQUIRE(
-        tiledb_config_set(
-            config,
-            "vfs.azure.storage_account_key",
-            "Eby8vdM02xNOcqFlqUwJPLlmEtlCDXJ1OUzFT50uSRZ6IFsuFq2UVErCz4I6tq/"
-            "K1SZFPTOtr/KBHBeksoGMGw==",
-            &error) == TILEDB_OK);
-    REQUIRE(
-        tiledb_config_set(
-            config,
-            "vfs.azure.blob_endpoint",
-            "http://127.0.0.1:10000/devstoreaccount1",
-            &error) == TILEDB_OK);
-  }
-
-  // Set number of threads across all backends.
-  REQUIRE(
-      tiledb_config_set(
-          config,
-          "vfs.s3.max_parallel_ops",
-          std::to_string(num_threads).c_str(),
-          &error) == TILEDB_OK);
-  // Set very small parallelization threshold (ignored when there is only 1
-  // thread).
-  REQUIRE(
-      tiledb_config_set(
-          config, "vfs.min_parallel_size", std::to_string(1).c_str(), &error) ==
-      TILEDB_OK);
-  REQUIRE(error == nullptr);
-
-  REQUIRE(tiledb_ctx_alloc(config, &ctx_) == TILEDB_OK);
-  REQUIRE(error == nullptr);
-  int rc = tiledb_vfs_alloc(ctx_, config, &vfs_);
-  REQUIRE(rc == TILEDB_OK);
-  tiledb_config_free(&config);
-}
-
 void VFSFx::check_vfs(const std::string& path) {
-  if (supports_s3_) {
+  if constexpr (tiledb::sm::filesystem::s3_enabled) {
     // Check S3 bucket functionality
     if (path == S3_TEMP_DIR) {
       int is_bucket = 0;
@@ -322,29 +229,35 @@ void VFSFx::check_vfs(const std::string& path) {
   // Ls
   check_ls(path);
 
-  if (supports_s3_ && path == S3_TEMP_DIR) {
-    int is_empty;
-    rc = tiledb_vfs_is_empty_bucket(ctx_, vfs_, S3_BUCKET.c_str(), &is_empty);
-    REQUIRE(rc == TILEDB_OK);
-    REQUIRE(!(bool)is_empty);
+  if constexpr (tiledb::sm::filesystem::s3_enabled) {
+    if (path == S3_TEMP_DIR) {
+      int is_empty;
+      rc = tiledb_vfs_is_empty_bucket(ctx_, vfs_, S3_BUCKET.c_str(), &is_empty);
+      REQUIRE(rc == TILEDB_OK);
+      REQUIRE(!(bool)is_empty);
+    }
   }
 
-  if (!supports_s3_) {
-    rc = tiledb_vfs_remove_dir(ctx_, vfs_, path.c_str());
-    REQUIRE(rc == TILEDB_OK);
+  if constexpr (!tiledb::sm::filesystem::s3_enabled) {
+    if (path != FILE_TEMP_DIR) {
+      rc = tiledb_vfs_remove_dir(ctx_, vfs_, path.c_str());
+      REQUIRE(rc == TILEDB_OK);
+    }
   }
 
-  if (supports_s3_ && path == S3_TEMP_DIR) {
-    rc = tiledb_vfs_empty_bucket(ctx_, vfs_, S3_BUCKET.c_str());
-    REQUIRE(rc == TILEDB_OK);
+  if constexpr (tiledb::sm::filesystem::s3_enabled) {
+    if (path == S3_TEMP_DIR) {
+      rc = tiledb_vfs_empty_bucket(ctx_, vfs_, S3_BUCKET.c_str());
+      REQUIRE(rc == TILEDB_OK);
 
-    int is_empty;
-    rc = tiledb_vfs_is_empty_bucket(ctx_, vfs_, S3_BUCKET.c_str(), &is_empty);
-    REQUIRE(rc == TILEDB_OK);
-    REQUIRE((bool)is_empty);
+      int is_empty;
+      rc = tiledb_vfs_is_empty_bucket(ctx_, vfs_, S3_BUCKET.c_str(), &is_empty);
+      REQUIRE(rc == TILEDB_OK);
+      REQUIRE((bool)is_empty);
 
-    rc = tiledb_vfs_remove_bucket(ctx_, vfs_, S3_BUCKET.c_str());
-    REQUIRE(rc == TILEDB_OK);
+      rc = tiledb_vfs_remove_bucket(ctx_, vfs_, S3_BUCKET.c_str());
+      REQUIRE(rc == TILEDB_OK);
+    }
   }
 }
 
@@ -438,7 +351,7 @@ void VFSFx::check_move(const std::string& path) {
   REQUIRE(is_file);
 
   // Move from one bucket to another (only for S3)
-  if (supports_s3_) {
+  if constexpr (tiledb::sm::filesystem::s3_enabled) {
     if (path == S3_TEMP_DIR) {
       std::string bucket2 = S3_PREFIX + random_name("tiledb") + "/";
       std::string subdir3 = bucket2 + "tiledb_test/subdir3/";
@@ -470,8 +383,9 @@ void VFSFx::check_move(const std::string& path) {
 #ifndef _WIN32
 void VFSFx::check_copy(const std::string& path) {
   // Do not support HDFS
-  if (supports_hdfs_)
+  if constexpr (tiledb::sm::filesystem::hdfs_enabled) {
     return;
+  }
 
   // Copy file
   auto file = path + "file";
@@ -550,7 +464,7 @@ void VFSFx::check_copy(const std::string& path) {
   REQUIRE(is_file);
 
   // Copy from one bucket to another (only for S3)
-  if (supports_s3_) {
+  if constexpr (tiledb::sm::filesystem::s3_enabled) {
     std::string bucket2 = S3_PREFIX + random_name("tiledb") + "/";
     std::string subdir3 = bucket2 + "tiledb_test/subdir3/";
     std::string file3 = subdir3 + "file2";
@@ -894,11 +808,11 @@ TEST_CASE_METHOD(VFSFx, "C API: Test virtual filesystem", "[capi][vfs]") {
   tiledb_stats_enable();
   tiledb_stats_reset();
 
-  if (supports_s3_)
+  if constexpr (tiledb::sm::filesystem::s3_enabled) {
     check_vfs(S3_TEMP_DIR);
-  else if (supports_hdfs_)
+  } else if constexpr (tiledb::sm::filesystem::hdfs_enabled) {
     check_vfs(HDFS_TEMP_DIR);
-  else {
+  } else {
     check_vfs(FILE_TEMP_DIR);
     check_vfs(MEMFS_TEMP_DIR);
   }
@@ -908,7 +822,7 @@ TEST_CASE_METHOD(
     VFSFx,
     "C API: Test virtual filesystem when S3 is not supported",
     "[capi][vfs]") {
-  if (!supports_s3_) {
+  if constexpr (!tiledb::sm::filesystem::s3_enabled) {
     tiledb_vfs_t* vfs;
     int rc = tiledb_vfs_alloc(ctx_, nullptr, &vfs);
     REQUIRE(rc == TILEDB_OK);
@@ -953,11 +867,29 @@ TEST_CASE_METHOD(
 TEST_CASE_METHOD(VFSFx, "C API: Test VFS parallel I/O", "[capi][vfs]") {
   tiledb_stats_enable();
   tiledb_stats_reset();
-  set_num_vfs_threads(4);
 
-  if (supports_s3_) {
+  tiledb_config_t* config;
+  REQUIRE(tiledb_vfs_get_config(ctx_, vfs_, &config) == TILEDB_OK);
+
+  // Set number of threads to 4.
+  tiledb_error_t* error = nullptr;
+  REQUIRE(
+      tiledb_config_set(
+          config,
+          "vfs.s3.max_parallel_ops",
+          std::to_string(4).c_str(),
+          &error) == TILEDB_OK);
+  // Set very small parallelization threshold (ignored when there is only 1
+  // thread).
+  REQUIRE(
+      tiledb_config_set(
+          config, "vfs.min_parallel_size", std::to_string(1).c_str(), &error) ==
+      TILEDB_OK);
+  REQUIRE(error == nullptr);
+
+  if constexpr (tiledb::sm::filesystem::s3_enabled) {
     check_vfs(S3_TEMP_DIR);
-  } else if (supports_hdfs_) {
+  } else if constexpr (tiledb::sm::filesystem::hdfs_enabled) {
     check_vfs(HDFS_TEMP_DIR);
   } else {
     check_vfs(FILE_TEMP_DIR);
