@@ -5,7 +5,7 @@
  *
  * The MIT License
  *
- * @copyright Copyright (c) 2020-2021 TileDB, Inc.
+ * @copyright Copyright (c) 2020-2023 TileDB, Inc.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -46,31 +46,23 @@
 #include "test/support/src/helpers.h"
 #include "test/support/src/vfs_helpers.h"
 
-namespace tiledb {
-namespace test {
+namespace tiledb::test {
 
 std::vector<std::unique_ptr<SupportedFs>> vfs_test_get_fs_vec() {
   std::vector<std::unique_ptr<SupportedFs>> fs_vec;
-
-  bool supports_s3 = false;
-  bool supports_hdfs = false;
-  bool supports_azure = false;
-  bool supports_gcs = false;
-  get_supported_fs(
-      &supports_s3, &supports_hdfs, &supports_azure, &supports_gcs);
-  if (supports_s3) {
+  if constexpr (tiledb::sm::filesystem::s3_enabled) {
     fs_vec.emplace_back(std::make_unique<SupportedFsS3>());
   }
 
-  if (supports_hdfs) {
+  if constexpr (tiledb::sm::filesystem::hdfs_enabled) {
     fs_vec.emplace_back(std::make_unique<SupportedFsHDFS>());
   }
 
-  if (supports_azure) {
+  if constexpr (tiledb::sm::filesystem::azure_enabled) {
     fs_vec.emplace_back(std::make_unique<SupportedFsAzure>());
   }
 
-  if (supports_gcs) {
+  if constexpr (tiledb::sm::filesystem::gcs_enabled) {
     fs_vec.emplace_back(std::make_unique<SupportedFsGCS>());
     fs_vec.emplace_back(std::make_unique<SupportedFsGCS>("gs://"));
   }
@@ -415,5 +407,4 @@ std::string TemporaryDirectoryFixture::create_temporary_array(
   return array_uri;
 }
 
-}  // End of namespace test
-}  // End of namespace tiledb
+}  // namespace tiledb::test
