@@ -5,7 +5,7 @@
  *
  * The MIT License
  *
- * @copyright Copyright (c) 2022 TileDB, Inc.
+ * @copyright Copyright (c) 2022-2023 TileDB, Inc.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -40,6 +40,7 @@
 #include "tiledb/sm/query/query.h"
 #include "tiledb/sm/stats/global_stats.h"
 #include "tiledb/sm/storage_manager/storage_manager.h"
+#include "tiledb/storage_format/uri/generate_uri.h"
 #include "tiledb/storage_format/uri/parse_uri.h"
 
 #include <iostream>
@@ -107,7 +108,7 @@ Status FragmentConsolidator::consolidate(
   // must be fetched (even before `config_.timestamp_start_`),
   // to compute the anterior ND range that can help determine
   // which dense fragments are consolidatable.
-  FragmentInfo fragment_info(URI(array_name), storage_manager_);
+  FragmentInfo fragment_info(URI(array_name), storage_manager_->resources());
   auto st = fragment_info.load(
       array_for_reads->array_directory(),
       config_.timestamp_start_,
@@ -216,7 +217,7 @@ Status FragmentConsolidator::consolidate_fragments(
   }
 
   // Get all fragment info
-  FragmentInfo fragment_info(URI(array_name), storage_manager_);
+  FragmentInfo fragment_info(URI(array_name), storage_manager_->resources());
   auto st = fragment_info.load(
       array_for_reads->array_directory(),
       0,
@@ -371,7 +372,7 @@ Status FragmentConsolidator::consolidate_internal(
     URI* new_fragment_uri) {
   auto timer_se = stats_->start_timer("consolidate_internal");
 
-  RETURN_NOT_OK(array_for_reads->load_fragments(to_consolidate));
+  array_for_reads->load_fragments(to_consolidate);
 
   if (array_for_reads->is_empty()) {
     return Status::Ok();
@@ -592,7 +593,14 @@ FragmentConsolidator::create_buffers(
 
   // Use the old buffer size setting to see how much memory we would use.
   auto buffer_num = buffer_weights.size();
-  uint64_t total_budget = config.buffer_size_ * buffer_num;
+  uint64_t total_budget = config.total_buffer_size_;
+
+  // If a user set the per-attribute buffer size configuration, we override
+  // the use of the total_budget_size config setting for backwards
+  // compatible behavior.
+  if (config.buffer_size_ != 0) {
+    total_budget = config.buffer_size_ * buffer_num;
+  }
 
   // Create buffers.
   std::vector<ByteVec> buffers(buffer_num);
@@ -649,9 +657,8 @@ Status FragmentConsolidator::create_queries(
   auto last = (*query_r)->last_fragment_uri();
 
   auto write_version = array_for_reads->array_schema_latest().write_version();
-  auto fragment_name =
-      array_for_reads->array_directory().compute_new_fragment_name(
-          first, last, write_version);
+  auto fragment_name = storage_format::generate_consolidated_fragment_name(
+      first, last, write_version);
 
   // Create write query
   *query_w = tdb_new(Query, storage_manager_, array_for_writes, fragment_name);
@@ -896,8 +903,22 @@ Status FragmentConsolidator::set_config(const Config& config) {
       "sm.consolidation.steps", &config_.steps_, &found));
   assert(found);
   config_.buffer_size_ = 0;
+  // Only set the buffer_size_ if the user specified a value. Otherwise, we use
+  // the new sm.consolidation.total_buffer_size instead.
+  if (merged_config.set_params().count("sm.consolidation.buffer_size") > 0) {
+    logger_->warn(
+        "The `sm.consolidation.buffer_size configuration setting has been "
+        "deprecated. Set consolidation buffer sizes using the newer "
+        "`sm.consolidation.total_buffer_size` setting.");
+    RETURN_NOT_OK(merged_config.get<uint64_t>(
+        "sm.consolidation.buffer_size", &config_.buffer_size_, &found));
+    assert(found);
+  }
+  config_.total_buffer_size_ = 0;
   RETURN_NOT_OK(merged_config.get<uint64_t>(
-      "sm.consolidation.buffer_size", &config_.buffer_size_, &found));
+      "sm.consolidation.total_buffer_size",
+      &config_.total_buffer_size_,
+      &found));
   assert(found);
   config_.max_fragment_size_ = 0;
   RETURN_NOT_OK(merged_config.get<uint64_t>(
