@@ -43,13 +43,12 @@
 #include "tiledb/sm/group/group_member_v2.h"
 #include "tiledb/sm/metadata/metadata.h"
 #include "tiledb/sm/misc/tdb_time.h"
-#include "tiledb/sm/misc/uuid.h"
 #include "tiledb/sm/rest/rest_client.h"
+#include "tiledb/storage_format/uri/generate_uri.h"
 
 using namespace tiledb::common;
 
-namespace tiledb {
-namespace sm {
+namespace tiledb::sm {
 
 class GroupStatusException : public StatusException {
  public:
@@ -68,8 +67,7 @@ Group::Group(const URI& group_uri, StorageManager* storage_manager)
     , query_type_(QueryType::READ)
     , timestamp_start_(0)
     , timestamp_end_(UINT64_MAX)
-    , encryption_key_(tdb::make_shared<EncryptionKey>(HERE()))
-    , changes_applied_(false) {
+    , encryption_key_(tdb::make_shared<EncryptionKey>(HERE())) {
 }
 
 Status Group::open(
@@ -110,6 +108,7 @@ Status Group::open(
 
   if (!encryption_key_from_cfg.empty()) {
     encryption_key = encryption_key_from_cfg.c_str();
+    key_length = static_cast<uint32_t>(encryption_key_from_cfg.size());
     std::string encryption_type_from_cfg;
     encryption_type_from_cfg = config_.get("sm.encryption_type", &found);
     assert(found);
@@ -117,16 +116,9 @@ Status Group::open(
     RETURN_NOT_OK(st);
     encryption_type = et.value();
 
-    if (EncryptionKey::is_valid_key_length(
+    if (!EncryptionKey::is_valid_key_length(
             encryption_type,
             static_cast<uint32_t>(encryption_key_from_cfg.size()))) {
-      const UnitTestConfig& unit_test_cfg = UnitTestConfig::instance();
-      if (unit_test_cfg.array_encryption_key_length.is_set()) {
-        key_length = unit_test_cfg.array_encryption_key_length.get();
-      } else {
-        key_length = static_cast<uint32_t>(encryption_key_from_cfg.size());
-      }
-    } else {
       encryption_key = nullptr;
       key_length = 0;
     }
@@ -203,7 +195,6 @@ Status Group::open(
 
   query_type_ = query_type;
   is_open_ = true;
-  changes_applied_ = false;
 
   return Status::Ok();
 }
@@ -257,11 +248,6 @@ Status Group::close() {
         query_type_ == QueryType::WRITE ||
         query_type_ == QueryType::MODIFY_EXCLUSIVE) {
       try {
-        // If changes haven't been applied, apply them
-        if (!changes_applied_) {
-          group_details_->apply_pending_changes();
-          changes_applied_ = group_details_->changes_applied();
-        }
         throw_if_not_ok(storage_manager_->group_close_for_writes(this));
       } catch (StatusException& exc) {
         std::string msg = exc.what();
@@ -274,7 +260,8 @@ Status Group::close() {
   metadata_.clear();
   metadata_loaded_ = false;
   is_open_ = false;
-  return clear();
+  clear();
+  return Status::Ok();
 }
 
 bool Group::is_open() const {
@@ -526,9 +513,8 @@ void Group::set_config(Config config) {
   config_.inherit(config);
 }
 
-Status Group::clear() {
+void Group::clear() {
   group_details_->clear();
-  return Status::Ok();
 }
 
 void Group::add_member(const shared_ptr<GroupMember> group_member) {
@@ -606,22 +592,12 @@ const shared_ptr<GroupDirectory> Group::group_directory() const {
   return group_dir_;
 }
 
-tuple<Status, optional<URI>> Group::generate_detail_uri() const {
-  auto&& [st, name] = generate_name();
-  RETURN_NOT_OK_TUPLE(st, std::nullopt);
+URI Group::generate_detail_uri() const {
+  auto ts_name = tiledb::storage_format::generate_timestamped_name(
+      timestamp_end_, group_details_->version());
 
-  URI uri = group_uri_.join_path(constants::group_detail_dir_name)
-                .join_path(name.value());
-
-  return {Status::Ok(), uri};
-}
-
-bool Group::changes_applied() const {
-  return changes_applied_;
-}
-
-void Group::set_changes_applied(const bool changes_applied) {
-  changes_applied_ = changes_applied;
+  return group_uri_.join_path(constants::group_detail_dir_name)
+      .join_path(ts_name);
 }
 
 uint64_t Group::member_count() const {
@@ -714,22 +690,6 @@ std::string Group::dump(
 /*         PROTECTED METHODS         */
 /* ********************************* */
 
-tuple<Status, optional<std::string>> Group::generate_name() const {
-  std::string uuid;
-  RETURN_NOT_OK_TUPLE(uuid::generate_uuid(&uuid, false), std::nullopt);
-
-  const auto& version = group_details_->version();
-  auto timestamp =
-      (timestamp_end_ != 0) ? timestamp_end_ : utils::time::timestamp_now_ms();
-  std::stringstream ss;
-  ss << "__" << timestamp << "_" << timestamp << "_" << uuid;
-  if (version > 1) {
-    ss << "_" << version;
-  }
-
-  return {Status::Ok(), ss.str()};
-}
-
 void Group::load_metadata() {
   if (remote_) {
     auto rest_client = storage_manager_->rest_client();
@@ -746,5 +706,4 @@ void Group::load_metadata() {
   metadata_loaded_ = true;
 }
 
-}  // namespace sm
-}  // namespace tiledb
+}  // namespace tiledb::sm
