@@ -469,6 +469,30 @@ void basic_aggregation_test(std::vector<double> expected_results) {
   std::vector<uint8_t> validity_data = {0, 0, 1, 0, 1, 0, 1, 0, 1, 0};
 
   SECTION("No bitmap") {
+    ByteVecValue zero(8);
+    ByteVecValue full_tile_sum(8);
+    if constexpr (!std::is_same<RES, std::string>::value) {
+      zero.assign_as<typename tiledb::sm::sum_type_data<T>::sum_type>(0);
+      full_tile_sum.assign_as<typename tiledb::sm::sum_type_data<T>::sum_type>(
+          10);
+    }
+
+    auto tile_metadata_all_null = TileMetadata(
+        10,
+        10,
+        &fixed_data[0],
+        sizeof(T),
+        &fixed_data[0],
+        sizeof(T),
+        zero.data());
+    auto tile_metadata = TileMetadata(
+        10,
+        5,
+        &fixed_data[0],
+        sizeof(T),
+        &fixed_data[0],
+        sizeof(T),
+        full_tile_sum.data());
     if (aggregator.has_value()) {
       // Regular attribute.
       AggregateBuffer input_data{
@@ -476,6 +500,14 @@ void basic_aggregation_test(std::vector<double> expected_results) {
       aggregator->aggregate_data(input_data);
       aggregator->copy_to_user_buffer("Agg", buffers);
       check_value(RES(), res, expected_results[0]);
+
+      aggregator->aggregate_tile_with_frag_md(tile_metadata_all_null);
+      aggregator->copy_to_user_buffer("Agg", buffers);
+      check_value(RES(), res, expected_results[1]);
+
+      aggregator->aggregate_tile_with_frag_md(tile_metadata);
+      aggregator->copy_to_user_buffer("Agg", buffers);
+      check_value(RES(), res, expected_results[2]);
     }
 
     // Nullable attribute.
@@ -490,7 +522,17 @@ void basic_aggregation_test(std::vector<double> expected_results) {
         1};
     aggregator_nullable.aggregate_data(input_data2);
     aggregator_nullable.copy_to_user_buffer("Agg2", buffers);
-    check_value(RES(), res2, expected_results[1]);
+    check_value(RES(), res2, expected_results[3]);
+    check_validity<AGGREGATOR>(validity, 1);
+
+    aggregator_nullable.aggregate_tile_with_frag_md(tile_metadata_all_null);
+    aggregator_nullable.copy_to_user_buffer("Agg2", buffers);
+    check_value(RES(), res2, expected_results[4]);
+    check_validity<AGGREGATOR>(validity, 1);
+
+    aggregator_nullable.aggregate_tile_with_frag_md(tile_metadata);
+    aggregator_nullable.copy_to_user_buffer("Agg2", buffers);
+    check_value(RES(), res2, expected_results[5]);
     check_validity<AGGREGATOR>(validity, 1);
   }
 
@@ -502,13 +544,13 @@ void basic_aggregation_test(std::vector<double> expected_results) {
           2, 10, fixed_data.data(), nullopt, nullopt, false, bitmap.data(), 1};
       aggregator->aggregate_data(input_data);
       aggregator->copy_to_user_buffer("Agg", buffers);
-      check_value(RES(), res, expected_results[2]);
+      check_value(RES(), res, expected_results[6]);
 
       AggregateBuffer input_data2{
           0, 2, fixed_data.data(), nullopt, nullopt, false, bitmap.data(), 1};
       aggregator->aggregate_data(input_data2);
       aggregator->copy_to_user_buffer("Agg", buffers);
-      check_value(RES(), res, expected_results[3]);
+      check_value(RES(), res, expected_results[7]);
     }
 
     // Nullable attribute.
@@ -529,10 +571,10 @@ void basic_aggregation_test(std::vector<double> expected_results) {
       res2.data()[0] = '0';
     }
 
-    if (is_nan(expected_results[4])) {
+    if (is_nan(expected_results[8])) {
       CHECK(is_nan(*static_cast<RES*>(static_cast<void*>(res2.data()))));
     } else {
-      check_value(RES(), res2, expected_results[4]);
+      check_value(RES(), res2, expected_results[8]);
     }
     check_validity<AGGREGATOR>(validity, 0);
 
@@ -547,7 +589,7 @@ void basic_aggregation_test(std::vector<double> expected_results) {
         1};
     aggregator_nullable.aggregate_data(input_data4);
     aggregator_nullable.copy_to_user_buffer("Agg2", buffers);
-    check_value(RES(), res2, expected_results[5]);
+    check_value(RES(), res2, expected_results[9]);
     check_validity<AGGREGATOR>(validity, 1);
   }
 
@@ -566,7 +608,7 @@ void basic_aggregation_test(std::vector<double> expected_results) {
           1};
       aggregator->aggregate_data(input_data);
       aggregator->copy_to_user_buffer("Agg", buffers);
-      check_value(RES(), res, expected_results[6]);
+      check_value(RES(), res, expected_results[10]);
 
       AggregateBuffer input_data2{
           0,
@@ -579,7 +621,7 @@ void basic_aggregation_test(std::vector<double> expected_results) {
           1};
       aggregator->aggregate_data(input_data2);
       aggregator->copy_to_user_buffer("Agg", buffers);
-      check_value(RES(), res, expected_results[7]);
+      check_value(RES(), res, expected_results[11]);
     }
 
     // Nullable attribute.
@@ -594,7 +636,7 @@ void basic_aggregation_test(std::vector<double> expected_results) {
         1};
     aggregator_nullable.aggregate_data(input_data3);
     aggregator_nullable.copy_to_user_buffer("Agg2", buffers);
-    check_value(RES(), res2, expected_results[8]);
+    check_value(RES(), res2, expected_results[12]);
     check_validity<AGGREGATOR>(validity, 1);
 
     AggregateBuffer input_data4{
@@ -608,7 +650,7 @@ void basic_aggregation_test(std::vector<double> expected_results) {
         1};
     aggregator_nullable.aggregate_data(input_data4);
     aggregator_nullable.copy_to_user_buffer("Agg2", buffers);
-    check_value(RES(), res2, expected_results[9]);
+    check_value(RES(), res2, expected_results[13]);
     check_validity<AGGREGATOR>(validity, 1);
   }
 }
@@ -633,7 +675,7 @@ TEMPLATE_LIST_TEST_CASE(
   basic_aggregation_test<
       T,
       typename sum_type_data<T>::sum_type,
-      SumAggregator<T>>({27, 14, 11, 14, 0, 6, 29, 34, 22, 22});
+      SumAggregator<T>>({27, 27, 37, 14, 14, 24, 11, 14, 0, 6, 29, 34, 22, 22});
 }
 
 TEMPLATE_LIST_TEST_CASE(
@@ -643,7 +685,11 @@ TEMPLATE_LIST_TEST_CASE(
   typedef TestType T;
   basic_aggregation_test<T, double, MeanAggregator<T>>(
       {(27.0 / 8.0),
+       (27.0 / 8.0),
+       (37.0 / 13.0),
        (14.0 / 4.0),
+       (14.0 / 4.0),
+       (24.0 / 9.0),
        (11.0 / 3.0),
        (14.0 / 5.0),
        std::numeric_limits<double>::signaling_NaN(),
@@ -684,9 +730,9 @@ TEMPLATE_LIST_TEST_CASE(
     AggUnderTestMinMax) {
   typedef decltype(TestType::first) T;
   typedef decltype(TestType::second) AGG;
-  std::vector<double> res = {1, 2, 2, 1, 0, 2, 1, 1, 2, 2};
+  std::vector<double> res = {1, 1, 1, 2, 2, 1, 2, 1, 0, 2, 1, 1, 2, 2};
   if (std::is_same<AGG, MaxAggregator<T>>::value) {
-    res = {5, 5, 5, 5, 0, 4, 5, 5, 4, 4};
+    res = {5, 5, 5, 5, 5, 5, 5, 5, 0, 4, 5, 5, 4, 4};
   }
   basic_aggregation_test<T, T, AGG>(res);
 }
@@ -694,7 +740,7 @@ TEMPLATE_LIST_TEST_CASE(
 TEST_CASE(
     "Count aggregator: Basic aggregation",
     "[count-aggregator][basic-aggregation]") {
-  std::vector<double> res = {8, 8, 3, 5, 2, 5, 10, 13, 10, 13};
+  std::vector<double> res = {8, 18, 28, 8, 18, 28, 3, 5, 2, 5, 10, 13, 10, 13};
   basic_aggregation_test<uint8_t, uint64_t, CountAggregator>(res);
 }
 
@@ -703,7 +749,7 @@ TEMPLATE_LIST_TEST_CASE(
     "[null-count-aggregator][basic-aggregation]",
     FixedTypesUnderTest) {
   typedef TestType T;
-  std::vector<double> res = {0, 4, 0, 0, 2, 3, 0, 0, 3, 6};
+  std::vector<double> res = {0, 0, 0, 4, 14, 19, 0, 0, 2, 3, 0, 0, 3, 6};
   basic_aggregation_test<T, uint64_t, NullCountAggregator>(res);
 }
 
@@ -947,6 +993,24 @@ void basic_string_aggregation_test(std::vector<RES> expected_results) {
   std::vector<uint8_t> validity_data = {0, 0, 1, 0, 1, 0, 1, 0, 1, 0};
 
   SECTION("No bitmap") {
+    ByteVecValue unused(8);
+    auto tile_metadata_all_null = TileMetadata(
+        10,
+        10,
+        &var_data[offsets[0]],
+        offsets[1] - offsets[0],
+        &var_data[offsets[5]],
+        offsets[6] - offsets[5],
+        unused.data());
+    auto tile_metadata = TileMetadata(
+        10,
+        5,
+        &var_data[offsets[0]],
+        offsets[1] - offsets[0],
+        &var_data[offsets[5]],
+        offsets[6] - offsets[5],
+        unused.data());
+
     if (aggregator.has_value()) {
       // Regular attribute.
       AggregateBuffer input_data{
@@ -954,6 +1018,14 @@ void basic_string_aggregation_test(std::vector<RES> expected_results) {
       aggregator->aggregate_data(input_data);
       aggregator->copy_to_user_buffer("Agg", buffers);
       check_value_string(fixed_data, value_size, value, expected_results[0]);
+
+      aggregator->aggregate_tile_with_frag_md(tile_metadata_all_null);
+      aggregator->copy_to_user_buffer("Agg", buffers);
+      check_value_string(fixed_data, value_size, value, expected_results[1]);
+
+      aggregator->aggregate_tile_with_frag_md(tile_metadata);
+      aggregator->copy_to_user_buffer("Agg", buffers);
+      check_value_string(fixed_data, value_size, value, expected_results[2]);
     }
 
     // Nullable attribute.
@@ -968,8 +1040,16 @@ void basic_string_aggregation_test(std::vector<RES> expected_results) {
         1};
     aggregator_nullable.aggregate_data(input_data2);
     aggregator_nullable.copy_to_user_buffer("Agg2", buffers);
-    check_value_string(fixed_data2, value_size2, value2, expected_results[1]);
+    check_value_string(fixed_data2, value_size2, value2, expected_results[3]);
     check_validity<AGGREGATOR>(validity, 1);
+
+    aggregator_nullable.aggregate_tile_with_frag_md(tile_metadata_all_null);
+    aggregator_nullable.copy_to_user_buffer("Agg2", buffers);
+    check_value_string(fixed_data2, value_size2, value2, expected_results[4]);
+
+    aggregator_nullable.aggregate_tile_with_frag_md(tile_metadata);
+    aggregator_nullable.copy_to_user_buffer("Agg2", buffers);
+    check_value_string(fixed_data2, value_size2, value2, expected_results[5]);
   }
 
   SECTION("Regular bitmap") {
@@ -987,7 +1067,7 @@ void basic_string_aggregation_test(std::vector<RES> expected_results) {
           1};
       aggregator->aggregate_data(input_data);
       aggregator->copy_to_user_buffer("Agg", buffers);
-      check_value_string(fixed_data, value_size, value, expected_results[2]);
+      check_value_string(fixed_data, value_size, value, expected_results[6]);
 
       AggregateBuffer input_data2{
           0,
@@ -1000,7 +1080,7 @@ void basic_string_aggregation_test(std::vector<RES> expected_results) {
           1};
       aggregator->aggregate_data(input_data2);
       aggregator->copy_to_user_buffer("Agg", buffers);
-      check_value_string(fixed_data, value_size, value, expected_results[3]);
+      check_value_string(fixed_data, value_size, value, expected_results[7]);
     }
 
     // Nullable attribute.
@@ -1015,7 +1095,7 @@ void basic_string_aggregation_test(std::vector<RES> expected_results) {
         1};
     aggregator_nullable.aggregate_data(input_data3);
     aggregator_nullable.copy_to_user_buffer("Agg2", buffers);
-    check_value_string(fixed_data2, value_size2, value2, expected_results[4]);
+    check_value_string(fixed_data2, value_size2, value2, expected_results[8]);
     check_validity<AGGREGATOR>(validity, 0);
 
     AggregateBuffer input_data4{
@@ -1029,7 +1109,7 @@ void basic_string_aggregation_test(std::vector<RES> expected_results) {
         1};
     aggregator_nullable.aggregate_data(input_data4);
     aggregator_nullable.copy_to_user_buffer("Agg2", buffers);
-    check_value_string(fixed_data2, value_size2, value2, expected_results[5]);
+    check_value_string(fixed_data2, value_size2, value2, expected_results[9]);
     check_validity<AGGREGATOR>(validity, 1);
   }
 
@@ -1048,7 +1128,7 @@ void basic_string_aggregation_test(std::vector<RES> expected_results) {
           1};
       aggregator->aggregate_data(input_data);
       aggregator->copy_to_user_buffer("Agg", buffers);
-      check_value_string(fixed_data, value_size, value, expected_results[6]);
+      check_value_string(fixed_data, value_size, value, expected_results[10]);
 
       AggregateBuffer input_data2{
           0,
@@ -1061,7 +1141,7 @@ void basic_string_aggregation_test(std::vector<RES> expected_results) {
           1};
       aggregator->aggregate_data(input_data2);
       aggregator->copy_to_user_buffer("Agg", buffers);
-      check_value_string(fixed_data, value_size, value, expected_results[7]);
+      check_value_string(fixed_data, value_size, value, expected_results[11]);
     }
 
     // Nullable attribute.
@@ -1076,7 +1156,7 @@ void basic_string_aggregation_test(std::vector<RES> expected_results) {
         1};
     aggregator_nullable.aggregate_data(input_data3);
     aggregator_nullable.copy_to_user_buffer("Agg2", buffers);
-    check_value_string(fixed_data2, value_size2, value2, expected_results[8]);
+    check_value_string(fixed_data2, value_size2, value2, expected_results[12]);
     check_validity<AGGREGATOR>(validity, 1);
 
     AggregateBuffer input_data4{
@@ -1090,12 +1170,12 @@ void basic_string_aggregation_test(std::vector<RES> expected_results) {
         1};
     aggregator_nullable.aggregate_data(input_data4);
     aggregator_nullable.copy_to_user_buffer("Agg2", buffers);
-    check_value_string(fixed_data2, value_size2, value2, expected_results[9]);
+    check_value_string(fixed_data2, value_size2, value2, expected_results[13]);
     check_validity<AGGREGATOR>(validity, 1);
   }
 }
 
-typedef tuple<MinAggregator<std::string>, MinAggregator<std::string>>
+typedef tuple<MinAggregator<std::string>, MaxAggregator<std::string>>
     MinMaxAggUnderTest;
 TEMPLATE_LIST_TEST_CASE(
     "Min max aggregator: Basic string aggregation",
@@ -1103,9 +1183,36 @@ TEMPLATE_LIST_TEST_CASE(
     MinMaxAggUnderTest) {
   typedef TestType AGGREGATOR;
   std::vector<std::string> res = {
-      "1", "2222", "2222", "11", "", "2222", "1", "1", "2222", "2222"};
+      "1",
+      "1",
+      "1",
+      "2222",
+      "2222",
+      "11",
+      "2222",
+      "11",
+      "",
+      "2222",
+      "1",
+      "1",
+      "2222",
+      "2222"};
   if (std::is_same<AGGREGATOR, MaxAggregator<std::string>>::value) {
-    res = {"5555", "555", "5555", "5555", "", "4", "5555", "5555", "4", "4"};
+    res = {
+        "5555",
+        "5555",
+        "5555",
+        "555",
+        "555",
+        "5555",
+        "5555",
+        "5555",
+        "",
+        "4",
+        "5555",
+        "5555",
+        "4",
+        "4"};
   }
 
   basic_string_aggregation_test<AGGREGATOR, std::string>(res);
@@ -1114,7 +1221,7 @@ TEMPLATE_LIST_TEST_CASE(
 TEST_CASE(
     "NullCount aggregator: Basic string aggregation",
     "[null-count-aggregator][basic-string-aggregation]") {
-  std::vector<uint64_t> res = {0, 4, 0, 0, 2, 3, 0, 0, 3, 6};
+  std::vector<uint64_t> res = {0, 0, 0, 4, 14, 19, 0, 0, 2, 3, 0, 0, 3, 6};
   basic_string_aggregation_test<NullCountAggregator, uint64_t>(res);
 }
 
