@@ -228,7 +228,7 @@ Status DenseTiler<T>::get_tile(
     // Fill entire tile with MAX_UINT64
     std::vector<offsets_t> to_write(
         cell_num_in_tile, std::numeric_limits<offsets_t>::max());
-    RETURN_NOT_OK(tile_pos.write(to_write.data(), 0, tile_off_size));
+    tile_pos.write(to_write.data(), 0, tile_off_size);
     to_write.clear();
     to_write.shrink_to_fit();
 
@@ -250,10 +250,10 @@ Status DenseTiler<T>::get_tile(
     auto& tile_val = tile.var_tile();
     for (uint64_t i = 0; i < cell_num_in_tile; ++i) {
       pos = tile_pos_buff[i];
-      RETURN_NOT_OK(tile_off.write(&offset, tile_off_offset, sizeof(offset)));
+      tile_off.write(&offset, tile_off_offset, sizeof(offset));
       tile_off_offset += sizeof(offset);
       if (pos == std::numeric_limits<uint64_t>::max()) {  // Empty
-        RETURN_NOT_OK(tile_val.write_var(&fill_var[0], offset, cell_size));
+        tile_val.write_var(&fill_var[0], offset, cell_size);
         offset += cell_size;
       } else {  // Non-empty
         val_offset = ((offsets_bytesize_ == 8) ?
@@ -267,8 +267,7 @@ Status DenseTiler<T>::get_tile(
                             mul -
                         val_offset) :
                        buff_var_size - val_offset;
-        RETURN_NOT_OK(
-            tile_val.write_var(&buff_var[val_offset], offset, val_size));
+        tile_val.write_var(&buff_var[val_offset], offset, val_size);
         offset += val_size;
       }
     }
@@ -540,8 +539,7 @@ Status DenseTiler<T>::copy_tile(
   auto d = dim_num - 1;
   while (true) {
     // Copy a slab
-    RETURN_NOT_OK(
-        tile.write(&buff[sub_offsets[d]], tile_offsets[d], copy_nbytes));
+    tile.write(&buff[sub_offsets[d]], tile_offsets[d], copy_nbytes);
 
     // Advance cell coordinates, tile and buffer offsets
     auto last_dim_changed = d;
