@@ -35,7 +35,7 @@
 
 #ifdef TILEDB_SERIALIZATION
 
-#include "tiledb-rest.h"
+#include "tiledb-rest.capnp.h"
 
 #include "tiledb/common/heap_memory.h"
 #include "tiledb/common/logger_public.h"
